==> ejc-gdjgtask-impl-3.0.0-20220901.102341-72-sources.jar: com/ejianc/business/bean/WorkChangeHisEntity.java <==
package com.ejianc.business.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工作变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_work_change_his")
public class WorkChangeHisEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 任务编码
    @TableField(value="work_title")
    private String workTitle; // 现工作标题
    @TableField(value="task_title")
    private String taskTitle; // 任务标题
    @TableField(value="responsible_user_id")
    private String responsibleUserId; // 责任人id
    @TableField(value="responsible_user_name")
    private String responsibleUserName; // 责任人名称
    @TableField(value="responsible_dep_id")
    private String responsibleDepId; // 责任部门id
    @TableField(value="responsible_dep_name")
    private String responsibleDepName; // 责任部门名称
    @TableField(value="org_id")
    private Long orgId; //组织id
    @TableField(value="org_name")
    private String orgName;//组织名称
    @TableField(value="ask_complete_date")
    private Date askCompleteDate; // 要求完成时间
    @TableField(value="feedback_cycle")
    private String feedbackCycle; // 反馈周期
    @TableField(value="content_describe")
    private String contentDescribe; // 现工作内容描述
    @TableField(value="feedback_date")
    private Date feedbackDate; // 反馈日期
    @TableField(value="task_level")
    private Integer taskLevel; // 任务层级
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="task_status")
    private Integer taskStatus; // 任务状态 0--为开始，1--进行中,2--已完成,3--已关闭
    @TableField(value="whether_overdue")
    private Integer whetherOverdue; // 0--否--1---是
    @TableField(value="work_status")
    private Integer workStatus; // 0--未开始，1--进项中---2--已处理，3--已评论，4--已关闭，5--已完成
    @TableField(value="close_date")
    private Date closeDate; // 关闭时间
    @TableField(value="pid")
    private Long pid; // 
    @TableField(value="assing_user_names")
    private String assingUserNames; // 指派人名称
    @TableField(value="assing_dept_names")
    private String assingDeptNames; // 指派人部门
    @TableField(value="initiate_time")
    private Date initiateTime; // 发布日期
    @TableField(value="promoter_id")
    private Long promoterId; // 发起人
    @TableField(value="promoter_name")
    private String promoterName; //发起人名称
    @TableField(value="thread_uuid")
    private String threadUuid; // 
    @TableField(value="feedback_content")
    private String feedbackContent; // 反馈内容
    @TableField(value="advance_cycle_reminder_num")
    private Integer advanceCycleReminderNum; // 提前周期提醒天数
    @TableField(value="original_task_title")
    private String originalTaskTitle; // 原任务标题
    @TableField(value="original_content_describe")
    private String originalContentDescribe; // 原工作描述
    @TableField(value="change_type")
    private String changeType; // 变更类型: 1-增补项，2-删除项，3-变更项
    @TableField(value="target_id")
    private Long targetId; // 变更项原数据Id
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getWorkTitle() {
        return workTitle;
    }

    public void setWorkTitle(String workTitle) {
        this.workTitle = workTitle;
    }
    public String getTaskTitle() {
        return taskTitle;
    }

    public void setTaskTitle(String taskTitle) {
        this.taskTitle = taskTitle;
    }
    public String getResponsibleUserId() {
        return responsibleUserId;
    }

    public void setResponsibleUserId(String responsibleUserId) {
        this.responsibleUserId = responsibleUserId;
    }
    public String getResponsibleUserName() {
        return responsibleUserName;
    }

    public void setResponsibleUserName(String responsibleUserName) {
        this.responsibleUserName = responsibleUserName;
    }
    public String getResponsibleDepId() {
        return responsibleDepId;
    }

    public void setResponsibleDepId(String responsibleDepId) {
        this.responsibleDepId = responsibleDepId;
    }
    public String getResponsibleDepName() {
        return responsibleDepName;
    }

    public void setResponsibleDepName(String responsibleDepName) {
        this.responsibleDepName = responsibleDepName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Date getAskCompleteDate() {
        return askCompleteDate;
    }

    public void setAskCompleteDate(Date askCompleteDate) {
        this.askCompleteDate = askCompleteDate;
    }
    public String getFeedbackCycle() {
        return feedbackCycle;
    }

    public void setFeedbackCycle(String feedbackCycle) {
        this.feedbackCycle = feedbackCycle;
    }
    public String getContentDescribe() {
        return contentDescribe;
    }

    public void setContentDescribe(String contentDescribe) {
        this.contentDescribe = contentDescribe;
    }
    public Date getFeedbackDate() {
        return feedbackDate;
    }

    public void setFeedbackDate(Date feedbackDate) {
        this.feedbackDate = feedbackDate;
    }
    public Integer getTaskLevel() {
        return taskLevel;
    }

    public void setTaskLevel(Integer taskLevel) {
        this.taskLevel = taskLevel;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getTaskStatus() {
        return taskStatus;
    }

    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }
    public Integer getWhetherOverdue() {
        return whetherOverdue;
    }

    public void setWhetherOverdue(Integer whetherOverdue) {
        this.whetherOverdue = whetherOverdue;
    }
    public Integer getWorkStatus() {
        return workStatus;
    }

    public void setWorkStatus(Integer workStatus) {
        this.workStatus = workStatus;
    }
    public Date getCloseDate() {
        return closeDate;
    }

    public void setCloseDate(Date closeDate) {
        this.closeDate = closeDate;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getAssingUserNames() {
        return assingUserNames;
    }

    public void setAssingUserNames(String assingUserNames) {
        this.assingUserNames = assingUserNames;
    }
    public String getAssingDeptNames() {
        return assingDeptNames;
    }

    public void setAssingDeptNames(String assingDeptNames) {
        this.assingDeptNames = assingDeptNames;
    }
    public Date getInitiateTime() {
        return initiateTime;
    }

    public void setInitiateTime(Date initiateTime) {
        this.initiateTime = initiateTime;
    }
    public Long getPromoterId() {
        return promoterId;
    }

    public void setPromoterId(Long promoterId) {
        this.promoterId = promoterId;
    }

    public String getPromoterName() {
        return promoterName;
    }

    public void setPromoterName(String promoterName) {
        this.promoterName = promoterName;
    }

    public String getThreadUuid() {
        return threadUuid;
    }

    public void setThreadUuid(String threadUuid) {
        this.threadUuid = threadUuid;
    }
    public String getFeedbackContent() {
        return feedbackContent;
    }

    public void setFeedbackContent(String feedbackContent) {
        this.feedbackContent = feedbackContent;
    }
    public Integer getAdvanceCycleReminderNum() {
        return advanceCycleReminderNum;
    }

    public void setAdvanceCycleReminderNum(Integer advanceCycleReminderNum) {
        this.advanceCycleReminderNum = advanceCycleReminderNum;
    }
    public String getOriginalTaskTitle() {
        return originalTaskTitle;
    }

    public void setOriginalTaskTitle(String originalTaskTitle) {
        this.originalTaskTitle = originalTaskTitle;
    }
    public String getOriginalContentDescribe() {
        return originalContentDescribe;
    }

    public void setOriginalContentDescribe(String originalContentDescribe) {
        this.originalContentDescribe = originalContentDescribe;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getTargetId() {
        return targetId;
    }

    public void setTargetId(Long targetId) {
        this.targetId = targetId;
    }
    
}

==> ejc-gdjgtask-impl-3.0.0-20220906.083925-78-sources.jar: com/ejianc/business/bean/WorkChangeHisEntity.java <==
package com.ejianc.business.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工作变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_work_change_his")
public class WorkChangeHisEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 任务编码
    @TableField(value="work_title")
    private String workTitle; // 现工作标题
    @TableField(value="task_title")
    private String taskTitle; // 任务标题
    @TableField(value="responsible_user_id")
    private String responsibleUserId; // 责任人id
    @TableField(value="responsible_user_name")
    private String responsibleUserName; // 责任人名称
    @TableField(value="responsible_dep_id")
    private String responsibleDepId; // 责任部门id
    @TableField(value="responsible_dep_name")
    private String responsibleDepName; // 责任部门名称
    @TableField(value="org_id")
    private String orgId; //组织id
    @TableField(value="org_name")
    private String orgName;//组织名称
    @TableField(value="ask_complete_date")
    private Date askCompleteDate; // 要求完成时间
    @TableField(value="feedback_cycle")
    private String feedbackCycle; // 反馈周期
    @TableField(value="content_describe")
    private String contentDescribe; // 现工作内容描述
    @TableField(value="feedback_date")
    private Date feedbackDate; // 反馈日期
    @TableField(value="task_level")
    private Integer taskLevel; // 任务层级
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="task_status")
    private Integer taskStatus; // 任务状态 0--为开始，1--进行中,2--已完成,3--已关闭
    @TableField(value="whether_overdue")
    private Integer whetherOverdue; // 0--否--1---是
    @TableField(value="work_status")
    private Integer workStatus; // 0--未开始，1--进项中---2--已处理，3--已评论，4--已关闭，5--已完成
    @TableField(value="close_date")
    private Date closeDate; // 关闭时间
    @TableField(value="pid")
    private Long pid; // 
    @TableField(value="assing_user_names")
    private String assingUserNames; // 指派人名称
    @TableField(value="assing_dept_names")
    private String assingDeptNames; // 指派人部门
    @TableField(value="initiate_time")
    private Date initiateTime; // 发布日期
    @TableField(value="promoter_id")
    private Long promoterId; // 发起人
    @TableField(value="promoter_name")
    private String promoterName; //发起人名称
    @TableField(value="thread_uuid")
    private String threadUuid; // 
    @TableField(value="feedback_content")
    private String feedbackContent; // 反馈内容
    @TableField(value="advance_cycle_reminder_num")
    private Integer advanceCycleReminderNum; // 提前周期提醒天数
    @TableField(value="original_task_title")
    private String originalTaskTitle; // 原任务标题
    @TableField(value="original_content_describe")
    private String originalContentDescribe; // 原工作描述
    @TableField(value="change_type")
    private String changeType; // 变更类型: 1-增补项，2-删除项，3-变更项
    @TableField(value="target_id")
    private Long targetId; // 变更项原数据Id
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getWorkTitle() {
        return workTitle;
    }

    public void setWorkTitle(String workTitle) {
        this.workTitle = workTitle;
    }
    public String getTaskTitle() {
        return taskTitle;
    }

    public void setTaskTitle(String taskTitle) {
        this.taskTitle = taskTitle;
    }
    public String getResponsibleUserId() {
        return responsibleUserId;
    }

    public void setResponsibleUserId(String responsibleUserId) {
        this.responsibleUserId = responsibleUserId;
    }
    public String getResponsibleUserName() {
        return responsibleUserName;
    }

    public void setResponsibleUserName(String responsibleUserName) {
        this.responsibleUserName = responsibleUserName;
    }
    public String getResponsibleDepId() {
        return responsibleDepId;
    }

    public void setResponsibleDepId(String responsibleDepId) {
        this.responsibleDepId = responsibleDepId;
    }
    public String getResponsibleDepName() {
        return responsibleDepName;
    }

    public void setResponsibleDepName(String responsibleDepName) {
        this.responsibleDepName = responsibleDepName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Date getAskCompleteDate() {
        return askCompleteDate;
    }

    public void setAskCompleteDate(Date askCompleteDate) {
        this.askCompleteDate = askCompleteDate;
    }
    public String getFeedbackCycle() {
        return feedbackCycle;
    }

    public void setFeedbackCycle(String feedbackCycle) {
        this.feedbackCycle = feedbackCycle;
    }
    public String getContentDescribe() {
        return contentDescribe;
    }

    public void setContentDescribe(String contentDescribe) {
        this.contentDescribe = contentDescribe;
    }
    public Date getFeedbackDate() {
        return feedbackDate;
    }

    public void setFeedbackDate(Date feedbackDate) {
        this.feedbackDate = feedbackDate;
    }
    public Integer getTaskLevel() {
        return taskLevel;
    }

    public void setTaskLevel(Integer taskLevel) {
        this.taskLevel = taskLevel;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getTaskStatus() {
        return taskStatus;
    }

    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }
    public Integer getWhetherOverdue() {
        return whetherOverdue;
    }

    public void setWhetherOverdue(Integer whetherOverdue) {
        this.whetherOverdue = whetherOverdue;
    }
    public Integer getWorkStatus() {
        return workStatus;
    }

    public void setWorkStatus(Integer workStatus) {
        this.workStatus = workStatus;
    }
    public Date getCloseDate() {
        return closeDate;
    }

    public void setCloseDate(Date closeDate) {
        this.closeDate = closeDate;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getAssingUserNames() {
        return assingUserNames;
    }

    public void setAssingUserNames(String assingUserNames) {
        this.assingUserNames = assingUserNames;
    }
    public String getAssingDeptNames() {
        return assingDeptNames;
    }

    public void setAssingDeptNames(String assingDeptNames) {
        this.assingDeptNames = assingDeptNames;
    }
    public Date getInitiateTime() {
        return initiateTime;
    }

    public void setInitiateTime(Date initiateTime) {
        this.initiateTime = initiateTime;
    }
    public Long getPromoterId() {
        return promoterId;
    }

    public void setPromoterId(Long promoterId) {
        this.promoterId = promoterId;
    }

    public String getPromoterName() {
        return promoterName;
    }

    public void setPromoterName(String promoterName) {
        this.promoterName = promoterName;
    }

    public String getThreadUuid() {
        return threadUuid;
    }

    public void setThreadUuid(String threadUuid) {
        this.threadUuid = threadUuid;
    }
    public String getFeedbackContent() {
        return feedbackContent;
    }

    public void setFeedbackContent(String feedbackContent) {
        this.feedbackContent = feedbackContent;
    }
    public Integer getAdvanceCycleReminderNum() {
        return advanceCycleReminderNum;
    }

    public void setAdvanceCycleReminderNum(Integer advanceCycleReminderNum) {
        this.advanceCycleReminderNum = advanceCycleReminderNum;
    }
    public String getOriginalTaskTitle() {
        return originalTaskTitle;
    }

    public void setOriginalTaskTitle(String originalTaskTitle) {
        this.originalTaskTitle = originalTaskTitle;
    }
    public String getOriginalContentDescribe() {
        return originalContentDescribe;
    }

    public void setOriginalContentDescribe(String originalContentDescribe) {
        this.originalContentDescribe = originalContentDescribe;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getTargetId() {
        return targetId;
    }

    public void setTargetId(Long targetId) {
        this.targetId = targetId;
    }
    
}
